## install 
```bash
pip install verify_domain_cert

```

## usage

```bash
verify_domain_cert https://www.google.com https://www.baidu.com

```

```python

from verify_domain_cert.check import get_certificate

get_certificate("https://www.google.com")

```